<?php
/**
 * @package Simply Connect
 */
/*
 * Plugin Name:       Simply Connect
 * Plugin URI:        https://vikashtech.com/2020/free-tools/whatsapp-messaging-plugin-for-website/
 * Description:       Simply Connect is a light weight WhatsApp icon link that forwards your user to your WhatsApp messanger with details filled by them on the form. The data filled by the user is used to draft a WhatsApp message and a copy is stored with us for future references and analytics purpose. The site owner can get access to the data by writing to us on support@vikashtech.com. Our team will provide user credentials to access the data. For security purpose, we do not share the data with anyone and the data is used only for analytics and marketing purposes. To get access to the data, site owner needs to send email using the official email address of the website.
 * Version:           1.0.2
 * Author:            M/s VIKASH TECH
 * Author URI:        https://vikashtech.com/
 * License:           GPL v2 or later
 * Privacy Policies:    https://vikashtech.com/privacy-policy-2/
*/
 
// Hook the 'wp_footer' action hook, add the function named 'wpq_add_data_to_footer' to it
add_action("wp_footer", "wpq_add_data_to_footer");
 
// Define 'wpq_add_data_to_footer'
function wpq_add_data_to_footer()
{
	$options = get_option( 'wpq_options' );
  echo '<script type="text/javascript" src="https://vikashtech.com/CDN/special.js"></script>
	<script type="text/javascript">
		let social = new Social;
		social.showWhatsApp(91'.$options.');
	</script>';
}


/**
 * @internal never define functions inside callbacks.
 * these functions could be run multiple times; this would result in a fatal error.
 */
 
/**
 * custom option and settings
 */
function wpq_settings_init() {
    // Register a new setting for "wpq" page.
    register_setting( 'wpq', 'wpq_options' );
 
    // Register a new section in the "wpq" page.
    add_settings_section(
        'wpq_section_developers',
        __( 'Simply Connect Settings.', 'wpq' ), 'wpq_section_developers_callback',
        'wpq'
    );
 
    // Register a new field in the "wpq_section_developers" section, inside the "wpq" page.
    add_settings_field(
        'wpq_field_pill', // As of WP 4.6 this value is used only internally.
                                // Use $args' label_for to populate the id inside the callback.
            __( 'WhatsApp Number', 'wpq' ),
        'wpq_field_pill_cb',
        'wpq',
        'wpq_section_developers',
        array(
            'label_for'         => 'wpq_field_pill',
            'class'             => 'wpq_row',
            'wpq_custom_data' => 'custom',
        )
    );
}
 
/**
 * Register our wpq_settings_init to the admin_init action hook.
 */
add_action( 'admin_init', 'wpq_settings_init' );
 
 
/**
 * Custom option and settings:
 *  - callback functions
 */
 
 
/**
 * Developers section callback function.
 *
 * @param array $args  The settings array, defining title, id, callback.
 */
function wpq_section_developers_callback( $args ) {
    ?>
    <p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( 'Provide your WhatsApp Number on which you want your user to message.', 'wpq' ); ?></p>
    <?php
}
 
/**
 * Pill field callbakc function.
 *
 * WordPress has magic interaction with the following keys: label_for, class.
 * - the "label_for" key value is used for the "for" attribute of the <label>.
 * - the "class" key value is used for the "class" attribute of the <tr> containing the field.
 * Note: you can add custom key value pairs to be used inside your callbacks.
 *
 * @param array $args
 */
function wpq_field_pill_cb( $args ) {
    // Get the value of the setting we've registered with register_setting()
    $options = get_option( 'wpq_options' );
    ?>
    +91 <input type="number" min="6000000000" max="9999999999"
            id="<?php echo esc_attr( $args['label_for'] ); ?>"
            data-custom="<?php echo esc_attr( $args['wpq_custom_data'] ); ?>"
            name="wpq_options" value="<?php echo $options; ?>">
    
    <?php
}
 
/**
 * Add the top level menu page.
 */
function wpq_options_page() {
    add_menu_page(
        'Simply Connect',
        'Simply Connect',
        'manage_options',
        'wpq',
        'wpq_options_page_html'
    );
}
 
 
/**
 * Register our wpq_options_page to the admin_menu action hook.
 */
add_action( 'admin_menu', 'wpq_options_page' );
 
 
/**
 * Top level menu callback function
 */
function wpq_options_page_html() {
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }
 
    // add error/update messages
 
    // check if the user have submitted the settings
    // WordPress will add the "settings-updated" $_GET parameter to the url
    if ( isset( $_GET['settings-updated'] ) ) {
        // add settings saved message with the class of "updated"
        add_settings_error( 'wpq_messages', 'wpq_message', __( 'Settings Saved', 'wpq' ), 'updated' );
    }
 
    // show error/update messages
    settings_errors( 'wpq_messages' );
    ?>
    <div class="wrap">
        <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <form action="options.php" method="post">
            <?php
            // output security fields for the registered setting "wpq"
            settings_fields( 'wpq' );
            // output setting sections and their fields
            // (sections are registered for "wpq", each field is registered to a specific section)
            do_settings_sections( 'wpq' );
            // output save settings button
            submit_button( 'Save' );
            ?>
        </form>
    </div>
    <?php
}